@@ -16,6 +16,8 @@ lm.morantest.sad <- function (model, listw, zero.policy = FALSE,
     if (is.null(spChk)) spChk <- get.spChkOption()
     if (spChk && !chkIDs(u, listw))
 	stop("Check of data and weights ID integrity failed")
+    if (!(alternative %in% c("greater", "less", "two.sided")))
+	stop("alternative must be one of: \"greater\", \"less\", or \"two.sided\"")
     u <- as.vector(u)
     listw.U <- listw2U(listw)
     S0 <- sum(unlist(listw.U$weights))
@@ -46,7 +48,7 @@ lm.morantest.sad <- function (model, listw, zero.policy = FALSE,
     else sad.r <- sqrt(sum(log(1 - 2*omega*taumi)))
     sad.u <- omega * sqrt(2*sum(taumi^2 / (1 - (2*omega*taumi))^2))
     sad.p <- sad.r - ((1/sad.r)*log(sad.r/sad.u))
-    if (alternative == "two.sided") p.sad <- 2 * (1 - pnorm(sad.p))
+    if (alternative == "two.sided") p.sad <- 2 * pnorm(-abs(sad.p))
     else if (alternative == "greater")
         p.sad <- pnorm(sad.p, lower.tail=FALSE)
     else p.sad <- pnorm(sad.p)
